import * as runtime from '../../../lib/runtime.js';
import type { InitOverride, ApiResponse } from '../../../lib/runtime.js';
import type { SsProfile, SsProfileCreate, SsProfileList, SsProfileUpdate, SsoAccessTicketResponse, SsoTicketRequestJson, DeleteSelfServiceProfilesByIdRequest, GetSelfServiceProfilesByIdRequest, PatchSelfServiceProfilesByIdRequest, PostSsoTicketRequest } from '../models/index.js';
declare const BaseAPI: typeof runtime.BaseAPI;
/**
 *
 */
export declare class SelfServiceProfilesManager extends BaseAPI {
    /**
     * Deletes a self-service profile by Id.
     * Delete a self-service profile by Id
     *
     * @throws {RequiredError}
     */
    deleteSelfServiceProfiles(requestParameters: DeleteSelfServiceProfilesByIdRequest, initOverrides?: InitOverride): Promise<ApiResponse<void>>;
    /**
     * Retrieves self-service profiles. Currently only one profile can be created per tenant.
     * Retrieve self-service profiles
     *
     * @throws {RequiredError}
     */
    getSelfServiceProfiles(initOverrides?: InitOverride): Promise<ApiResponse<SsProfileList>>;
    /**
     * Retrieves a self-service profile by Id.
     * Retrieve a self-service profile by Id
     *
     * @throws {RequiredError}
     */
    getSelfServiceProfilesById(requestParameters: GetSelfServiceProfilesByIdRequest, initOverrides?: InitOverride): Promise<ApiResponse<SsProfile>>;
    /**
     * Updates a self-service profile.
     * Update a self-service profile
     *
     * @throws {RequiredError}
     */
    patchSelfServiceProfiles(requestParameters: PatchSelfServiceProfilesByIdRequest, bodyParameters: SsProfileUpdate, initOverrides?: InitOverride): Promise<ApiResponse<SsProfile>>;
    /**
     * Creates a self-service profile. Currently only one profile can be created per tenant.
     * Create a self-service profile
     *
     * @throws {RequiredError}
     */
    postSelfServiceProfiles(bodyParameters: SsProfileCreate, initOverrides?: InitOverride): Promise<ApiResponse<SsProfile>>;
    /**
     * Creates an sso-access ticket to initiate the Self Service SSO Flow using a self-service profile.
     * Create an sso-access ticket to initiate the Self Service SSO Flow
     *
     * @throws {RequiredError}
     */
    postSsoTicket(requestParameters: PostSsoTicketRequest, bodyParameters: SsoTicketRequestJson, initOverrides?: InitOverride): Promise<ApiResponse<SsoAccessTicketResponse>>;
}
export {};
